************
Installation
************

The recommended installation method is using ``pip``.

pip
===

.. code:: bash

   $ pip install pg_grant

To install with :mod:`sqlalchemy` support, install the sqlalchemy extra:

.. code:: bash

   $ pip install pg_grant[sqlalchemy]

Git
===

.. code-block:: sh

   $ git clone https://github.com/RazerM/pg_grant.git
   Cloning into 'pg_grant'...

Check out a `release tag`_

.. parsed-literal::

   $ cd pg_grant
   $ git checkout |version|

.. _`release tag`: https://github.com/RazerM/pg_grant/releases
